==> mlr3_0.14.1.tar.gz: mlr3/R/bibentries.R <==
#' @importFrom utils bibentry
bibentries = c(
  anderson_1936 = bibentry("article",
    doi       = "10.2307/2394164",
    year      = "1936",
    month     = "9",
    publisher = "JSTOR",
    volume    = "23",
    number    = "3",
    pages     = "457",
    author    = "Edgar Anderson",
    title     = "The Species Problem in Iris",
    journal   = "Annals of the Missouri Botanical Garden"
  ),

  bischl_2012 = bibentry("article",
    title = "Resampling Methods for Meta-Model Validation with Recommendations for Evolutionary Computation",
    author = "Bernd Bischl and Olaf Mersmann and Heike Trautmann and Claus Weihs",
    year = "2012",
    month = "jun",
    journal = "Evolutionary Computation",
    publisher = "MIT Press - Journals",
    volume = "20",
    number = "2",
    pages = "249--275",
    doi = "10.1162/evco_a_00069"
  ),

  breiman_1984 = bibentry("book",
    title        = "Classification And Regression Trees",
    author       = "Leo Breiman and Jerome H. Friedman and Richard A. Olshen and Charles J. Stone",
    year         = "1984",
    publisher    = "Routledge",
    doi          = "10.1201/9781315139470"
  ),

  dua_2017 = bibentry("misc",
    title        = "{UCI} Machine Learning Repository",
    author       = "Dua, Dheeru and Graff, Casey",
    year         = "2017",
    url          = "http://archive.ics.uci.edu/ml/",
    institution  = "University of California, Irvine, School of Information and Computer Sciences"
  ),

  gorman2014 = bibentry("article",
    doi       = "10.1371/journal.pone.0090081",
    year      = "2014",
    month     = "mar",
    publisher = "Public Library of Science ({PLoS})",
    volume    = "9",
    number    = "3",
    pages     = "e90081",
    author    = "Kristen B. Gorman and Tony D. Williams and William R. Fraser",
    editor    = "Andr\u00e8 Chiaradia",
    title     = "Ecological Sexual Dimorphism and Environmental Variability within a Community of Antarctic Penguins (Genus Pygoscelis)",
    journal   = "{PLoS} {ONE}"
  ),

  gromping_2019 = bibentry("techreport",
    title        = "South German Credit Data: Correcting a Widely Used Data Set",
    author       = "Ulrike Gr\u00f6mping",
    year         = "2019",
    number       = "4",
    url          = "http://www1.beuth-hochschule.de/FB_II/reports/Report-2019-004.pdf",
    type         = "Reports in Mathematics, Physics and Chemistry",
    institution  = "Department II, Beuth University of Applied Sciences Berlin"
  ),

  sasaki_2007 = bibentry("article",
    title        = "The truth of the F-measure",
    author       = "Sasaki, Yutaka",
    year         = "2007",
    journal      = "Teach Tutor mater",
    volume       = "1",
    number       = "5",
    pages        = "1--5",
    url          = "https://www.cs.odu.edu/~mukka/cs795sum10dm/Lecturenotes/Day3/F-measure-YS-26Oct07.pdf"
  )
)

==> mlr3_0.17.2.tar.gz: mlr3/R/bibentries.R <==
#' @importFrom utils bibentry
bibentries = c(
  anderson_1936 = bibentry("article",
    doi       = "10.2307/2394164",
    year      = "1936",
    month     = "9",
    publisher = "JSTOR",
    volume    = "23",
    number    = "3",
    pages     = "457",
    author    = "Edgar Anderson",
    title     = "The Species Problem in Iris",
    journal   = "Annals of the Missouri Botanical Garden"
  ),

  bischl_2012 = bibentry("article",
    title = "Resampling Methods for Meta-Model Validation with Recommendations for Evolutionary Computation",
    author = "Bernd Bischl and Olaf Mersmann and Heike Trautmann and Claus Weihs",
    year = "2012",
    month = "jun",
    journal = "Evolutionary Computation",
    publisher = "MIT Press - Journals",
    volume = "20",
    number = "2",
    pages = "249--275",
    doi = "10.1162/evco_a_00069"
  ),

  breiman_1984 = bibentry("book",
    title        = "Classification And Regression Trees",
    author       = "Leo Breiman and Jerome H. Friedman and Richard A. Olshen and Charles J. Stone",
    year         = "1984",
    publisher    = "Routledge",
    doi          = "10.1201/9781315139470"
  ),

  dua_2017 = bibentry("misc",
    title        = "{UCI} Machine Learning Repository",
    author       = "Dua, Dheeru and Graff, Casey",
    year         = "2017",
    url          = "http://archive.ics.uci.edu/datasets",
    institution  = "University of California, Irvine, School of Information and Computer Sciences"
  ),

  gorman2014 = bibentry("article",
    doi       = "10.1371/journal.pone.0090081",
    year      = "2014",
    month     = "mar",
    publisher = "Public Library of Science ({PLoS})",
    volume    = "9",
    number    = "3",
    pages     = "e90081",
    author    = "Kristen B. Gorman and Tony D. Williams and William R. Fraser",
    editor    = "Andr\u00e8 Chiaradia",
    title     = "Ecological Sexual Dimorphism and Environmental Variability within a Community of Antarctic Penguins (Genus Pygoscelis)",
    journal   = "{PLoS} {ONE}"
  ),

  gromping_2019 = bibentry("techreport",
    title        = "South German Credit Data: Correcting a Widely Used Data Set",
    author       = "Ulrike Gr\u00f6mping",
    year         = "2019",
    number       = "4",
    url          = "http://www1.beuth-hochschule.de/FB_II/reports/Report-2019-004.pdf",
    type         = "Reports in Mathematics, Physics and Chemistry",
    institution  = "Department II, Beuth University of Applied Sciences Berlin"
  ),

  sasaki_2007 = bibentry("article",
    title        = "The truth of the F-measure",
    author       = "Sasaki, Yutaka",
    year         = "2007",
    journal      = "Teach Tutor mater",
    volume       = "1",
    number       = "5",
    pages        = "1--5",
    url          = "https://www.cs.odu.edu/~mukka/cs795sum10dm/Lecturenotes/Day3/F-measure-YS-26Oct07.pdf"
  )
)
